package com.muyu.product.domain.model;

import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.product.domain.AsProductAttributeInfo;
import com.muyu.product.domain.ProjectInfo;
import com.muyu.product.domain.ProjectSkuInfo;
import com.muyu.product.domain.req.ProjectInfoQueryReq;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.List;

/**
 * 商品添加模型 ProjectAddModel
 *
 * @author LeYang
 * on 2024/3/22
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class ProjectAddModel extends BaseEntity {
    /**
     * 商品名称
     */
    @ApiModelProperty(name = "商品名称",value = "商品名称")
    private String name;

    /**
     * 商品描述
     */
    @ApiModelProperty(name = "商品描述",value = "商品描述")
    private String introduction;

    /**
     * 主类型
     */
    @ApiModelProperty(name = "主类型",value = "主类型")
    private String mianType;

    /**
     * 父类型
     */
    @ApiModelProperty(name = "父类型",value = "父类型")
    private String parentType;

    /**
     * 商品类型
     */
    @ApiModelProperty(name = "商品类型",value = "商品类型")
    private String type;

    /**
     * 商品图片
     */
    @ApiModelProperty(name = "商品图片",value = "商品图片")
    private String image;

    /**
     * 商品轮播图
     */
    @ApiModelProperty(name = "商品轮播图",value = "商品轮播图")
    private String carouselImages;

    /**
     * 商品状态
     */
    @ApiModelProperty(name = "商品状态",value = "商品状态")
    private String status;

    /**
     * 规格
     */
    @ApiModelProperty(name = "规格",value = "规格")
    private Long ruleId;

    /**
     * 品牌
     */
    @ApiModelProperty(name = "品牌",value = "品牌")
    private Long brandId;


    private List<AsProductAttributeInfo> asProductAttributeInfos;

     private List<ProjectSkuInfo> projectSkuInfos;

    public static ProjectAddModel queryBuild(ProjectInfo projectInfoQueryReq, List<AsProductAttributeInfo> asProductAttributeInfoList, List<ProjectSkuInfo> projectSkuInfoList){
        return ProjectAddModel.builder()
                .name(projectInfoQueryReq.getName())
                .introduction(projectInfoQueryReq.getIntroduction())
                .mianType(projectInfoQueryReq.getMianType())
                .parentType(projectInfoQueryReq.getParentType())
                .type(projectInfoQueryReq.getType())
                .image(projectInfoQueryReq.getImage())
                .carouselImages(projectInfoQueryReq.getCarouselImages())
                .status(projectInfoQueryReq.getStatus())
                .ruleId(projectInfoQueryReq.getRuleId())
                .brandId(projectInfoQueryReq.getBrandId())
                .projectSkuInfos(projectSkuInfoList)
                .asProductAttributeInfos(asProductAttributeInfoList)
                .build();
    }

}
